@@ -41,7 +41,6 @@ typedef struct xfs_inode_log_item {
 	unsigned short		ili_flags;		/* misc flags */
 	unsigned int		ili_fields;		/* fields to be logged */
 	unsigned int		ili_last_fields;	/* fields when flushed*/
-	xfs_inode_log_format_t	ili_format;		/* logged structure */
 } xfs_inode_log_item_t;
 
 typedef struct xfs_buf_log_item {
@@ -107,6 +106,7 @@ void	libxfs_trans_brelse(struct xfs_trans *, struct xfs_buf *);
 void	libxfs_trans_binval(struct xfs_trans *, struct xfs_buf *);
 void	libxfs_trans_bjoin(struct xfs_trans *, struct xfs_buf *);
 void	libxfs_trans_bhold(struct xfs_trans *, struct xfs_buf *);
+void	libxfs_trans_dirty_buf(struct xfs_trans *, struct xfs_buf *);
 void	libxfs_trans_log_buf(struct xfs_trans *, struct xfs_buf *,
 				uint, uint);
 bool	libxfs_trans_ordered_buf(xfs_trans_t *, struct xfs_buf *);
