@@ -65,6 +65,7 @@ typedef struct mmap_region {
 	size_t		length;		/* length of mapping */
 	off64_t		offset;		/* start offset into backing file */
 	int		prot;		/* protection mode of the mapping */
+	bool		map_sync;	/* is this a MAP_SYNC mapping? */
 	char		*name;		/* name of backing file */
 } mmap_region_t;
 
@@ -185,3 +186,11 @@ extern void		fsmap_init(void);
 #else
 # define fsmap_init()	do { } while (0)
 #endif
+
+#ifdef HAVE_DEVMAPPER
+extern void		log_writes_init(void);
+#else
+#define log_writes_init()      do { } while (0)
+#endif
+
+extern void		scrub_init(void);
