@@ -62,6 +62,20 @@ struct fdhash {
 
 static struct fdhash *fdhash_head = NULL;
 
+void
+fshandle_destroy(void)
+{
+	struct fdhash	*nexth;
+	struct fdhash	*h = fdhash_head;
+
+	while (h) {
+		nexth = h->fnxt;
+		free(h);
+		h = nexth;
+	}
+	fdhash_head = NULL;
+}
+
 int
 path_to_fshandle(
 	char		*path,		/* input,  path to convert */
@@ -232,7 +246,7 @@ obj_to_handle(
 {
 	char		hbuf [MAXHANSIZ];
 	int		ret;
-	__uint32_t	handlen;
+	uint32_t	handlen;
 	xfs_fsop_handlereq_t hreq;
 
 	if (opcode == XFS_IOC_FD_TO_HANDLE) {
@@ -413,7 +427,7 @@ parents_by_handle(
 	parent_t	*buf,
 	size_t		bufsiz,
 	unsigned int	*count)
-	
+
 {
 	errno = EOPNOTSUPP;
 	return -1;
